# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['airflow_bio_utils',
 'airflow_bio_utils.cli',
 'airflow_bio_utils.fasta_metrics',
 'airflow_bio_utils.fasta_metrics.calc',
 'airflow_bio_utils.fasta_metrics.utils',
 'airflow_bio_utils.operators',
 'airflow_bio_utils.sequences',
 'airflow_bio_utils.sequences.filter']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=8.2.0,<9.0.0',
 'apache-airflow>=2.0.0',
 'biopython>=1.78,<2.0',
 'biotite>=0.27.0,<0.28.0',
 'bump2version>=1.0.1,<2.0.0',
 'click>=7.1.2,<8.0.0',
 'dvc-fs>=0.7.2,<0.8.0',
 'fpdf>=1.7.2,<2.0.0',
 'fs-s3fs>=1.1.1,<2.0.0',
 'fs>=2.4.13,<3.0.0',
 'matplotlib>=3.4.2,<4.0.0',
 'numpy>=1.20.3,<2.0.0',
 'pandas>=1.1.5,<2.0.0',
 'plotly>=4.14.3,<5.0.0',
 'pybloom3>=0.0.3,<0.0.4',
 'scipy>=1.6.3,<2.0.0',
 'simplesam>=0.1.3,<0.2.0',
 'tqdm>=4.56.0,<5.0.0']

entry_points = \
{'console_scripts': ['create-random-sequences = '
                     'airflow_bio_utils.cli.create_random_sequences:create_random_sequences_cli',
                     'filter-sequences = '
                     'airflow_bio_utils.cli.filter_sequences:filter_sequences_cli',
                     'merge-sequences = '
                     'airflow_bio_utils.cli.merge_sequences:merge_sequences_cli',
                     'publish = publish:publish']}

setup_kwargs = {
    'name': 'airflow-bio-utils',
    'version': '0.5.7',
    'description': 'Airflow utilities for biological sequences',
    'long_description': '# Airflow utils for biological sequences\n\n![version_badge](https://s3.eu-central-1.amazonaws.com/pypi.covidgenomics.com/__public__/utils/badge_version.svg)\n\n## Installation\n\nTo install this module please do:\n```bash\n   $ poetry install airflow-bio-utils@0.5.7\n   # or\n   $ pip install airflow-bio-utils==0.5.7\n```\n\n## Usage\n\n### Airflow operators\n\n#### Sequence merge\n\n`SequenceMergeOperator` takes input files and merges the sequences together.\nIt provides efficient antiduplication mechanism to remove duplicate IDs.\n\nMerging sequences from local paths:\n```python\nfrom airflow_bio_utils import SequenceMergeOperator\n\nmerge_fasta_files = SequenceMergeOperator(\n    [\'./a.fasta\', \'b.fasta\'],\n    \'output.fasta\',\n)\n```\n\nMerging sequences from remote locations:\n```python\nfrom airflow_bio_utils import SequenceMergeOperator\n\nmerge_fasta_files = SequenceMergeOperator(\n    [\n        "s3://bucket1//folder1/folder2/input1.fasta",\n        "s3://bucket1//folder1/folder2/input2.fasta",\n        "s3://other_bucket//some_folder/fasta_file.fasta",\n    ],\n    "s3://output_bucket/output.fasta",\n)\n```\n\n#### Generating random sequences\n\n`SequenceRandomOperator` can generate nucleotide or protein (translated) sequences with given lengths in given amounts.\n\n```python\nfrom airflow_bio_utils import SequenceRandomOperator\n\nrandom_sequence_generator_task = SequenceRandomOperator(\n    output="dvc://ssh@github.com/covid-genomics/data-artifacts//random.fasta",\n    count=130,\n    min_length=1000,\n    max_length=5000,\n)\n```\n\n#### Sequences metrics\n\n`SequenceMetricsOperator` allows you to measure qualities of `fastq` metrics, trace GC content, kmers and get other statistics.\nBy default it generated PDF report.\n\n```python\nfrom airflow_bio_utils import SequenceMetricsOperator\n\nSequenceMetricsOperator(\n    input_path="some_input.fasta",\n    output_path="dvc://<PAT>@github.com/covid-genomics/data-artifacts//output_metrics",\n)\n```\n\n#### Sequence filtering\n\n`SequenceFilterOperator` allows you to remove sequences based on simple criteria like length or nucleotide contents.\n\n```python\nfrom airflow_bio_utils import SequenceFilterOperator\n\nSequenceFilterOperator(\n    input_paths=["a.fasta", "b.fasta"],\n    min_seq_len=1000,\n    accepted_symbols=["A", "C", "T", "G", "N"],\n    output_paths=["a_filtered.fasta", "b_filtered.fasta"],\n)\n```\n\n#### Sequence for each\n\n`SequenceForEachOperator` takes an action and executes it for each sequence.\nThe action can return None or sequence and if you specify `output_path` parameter,\nall results will be saved into new fasta file.\nThis makes `SequenceForEachOperator` foreach or map/filter operator.\n\n```python\nfrom airflow_bio_utils import SequenceForEachOperator\n\ntask = SequenceForEachOperator(\n    sequences="sequences.fasta",\n    action=lambda seq: seq,\n    output_path="output.fasta",\n)\n```\n\n### CLI\n\nThe package provides useful utilities for IO operations, transformations of biological data and reusable algorithms.\nIt also provides CLI interfaces for useful commands:\n```bash\n    $ poetry run create-random-sequences --help\n    $ poetry run filter-sequences --help\n    $ poetry run merge-sequences --help\n```\n\n## Development\n\nTo test the package please run:\n```bash\n    $ make test\n```\n\nRun linter with:\n```bash\n    $ make lint\n```',
    'author': 'Piotr Styczyński',
    'author_email': 'piotr@styczynski.in',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<3.10',
}


setup(**setup_kwargs)
